"""
Simple_aws

SQS Functions

version .1
"""
import boto3

class sqsSimple(object):
    def __init__(self, **kwargs):
        """
        Initializes SQS connection and Queue
        """
        if 'region_name' in kwargs:
            region_name = kwargs['region_name']
        else: 
            region_name = aws_default_region
        if 'profile' in kwargs:
            profile = kwargs['profile']
        else:
            profile = aws_default_profile

        session = boto3.session.Session(profile_name=profile,
                                    region_name=region_name)     
        self.sqs = session.resource('sqs')
        if 'queue' not in kwargs:
            self.queue_name = sqs_default_queue
        else:
            self.queue_name = kwargs['queue']

        return

    def get_sqs_messages(self, **kwargs):
        """
        Get all tenant messages waiting in SQS Queue
        """
        queue = self.sqs.get_queue_by_name(QueueName=self.queue_name)
        if 'num_messages' in kwargs:
            num_messages = kwargs['num_messages']
        else:
            num_messages = sqs_default_messages
            
        messages = queue.receive_messages(MaxNumberOfMessages=num_messages)
        all_messages = []
        for message in messages:
            all_messages.append(message.body)
        
        return(all_messages)

    def send_sqs_message(self, **kwargs):
        """
        This will send an SQS message to the proper queue
        """

        if 'message' not in kwargs:
            return False

        queue = self.sqs.get_queue_by_name(QueueName=self.queue_name)
        queue.send_message(
            MessageBody=kwargs['message']
        )
            
        return

    def create_queue(self):
        """
        Create new SQS Queue
        """
        new_queue = self.sqs.create_queue(QueueName=self.queue_name)

        return
        
    def purge_queue(self):
        """
        Purge a specific queue
        """
        queue = self.sqs.get_queue_by_name(QueueName=self.queue_name)
        queue.purge()
        
        return

    def delete_queue(self):
        """
        Delete a specific queue
        """
        queue = self.sqs.get_queue_by_name(QueueName=self.queue_name)
        queue.delete()

        return